@@ -9,6 +9,7 @@ from fastflix.models.fastflix import FastFlix
 from fastflix.encoders.common.encc_helpers import (
     build_subtitle,
     build_audio,
+    build_data,
     rigaya_auto_options,
     rigaya_avformat_reader,
 )
@@ -82,6 +83,8 @@ def build(fastflix: FastFlix):
 
     if video.video_settings.remove_metadata:
         command.extend(["--video-metadata", "clear", "--metadata", "clear"])
+    elif video.video_settings.remove_hdr:
+        command.extend(["--video-metadata", "clear", "--metadata", "copy"])
     else:
         command.extend(["--video-metadata", "copy", "--metadata", "copy"])
 
@@ -142,9 +145,9 @@ def build(fastflix: FastFlix):
         )
     if fastflix.current_video.cll:
         command.extend(["--max-cll", str(fastflix.current_video.cll)])
-    if settings.copy_hdr10:
+    if settings.copy_hdr10 and not video.video_settings.remove_hdr:
         command.extend(["--dhdr10-info", "copy"])
-    if settings.copy_dv:
+    if settings.copy_dv and not video.video_settings.remove_hdr:
         command.extend(["--dolby-vision-rpu", "copy"])
         command.extend(["--dolby-vision-profile", "copy"])
 
@@ -175,6 +178,9 @@ def build(fastflix: FastFlix):
 
     command.extend(build_audio(video.audio_tracks, video.streams.audio))
     command.extend(build_subtitle(video.subtitle_tracks, video.streams.subtitle, video_height=video.height))
+    command.extend(
+        build_data(video.data_tracks, getattr(video.streams, "data", []), getattr(video.streams, "attachment", []))
+    )
 
     if settings.extra:
         command.extend(settings.extra.split())
